<?php

namespace Stripe\Issuing;

/**
 * Class Authorization
 *
 * @property string $id
 * @property string $object
 * @property bool $approved
 * @property string $authorization_method
 * @property int $authorized_amount
 * @property string $authorized_currency
 * @property \Stripe\BalanceTransaction[] $balance_transactions
 * @property \Stripe\Issuing\Card $card
 * @property string|\Stripe\Issuing\Cardholder|null $cardholder
 * @property int $created
 * @property int $held_amount
 * @property string $held_currency
 * @property bool $is_held_amount_controllable
 * @property bool $livemode
 * @property \Stripe\StripeObject $merchant_data
 * @property \Stripe\StripeObject $metadata
 * @property int $pending_authorized_amount
 * @property int $pending_held_amount
 * @property \Stripe\StripeObject[] $request_history
 * @property string $status
 * @property \Stripe\Issuing\Transaction[] $transactions
 * @property \Stripe\StripeObject $verification_data
 * @property string|null $wallet_provider
 *
 * @package Stripe\Issuing
 */
class Authorization extends \Stripe\ApiResource {

	const OBJECT_NAME = 'issuing.authorization';

	use \Stripe\ApiOperations\All;
	use \Stripe\ApiOperations\Retrieve;
	use \Stripe\ApiOperations\Update;

	/**
	 * @param array|null        $params
	 * @param array|string|null $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return Authorization The approved authorization.
	 */
	public function approve( $params = null, $opts = null ) {
		$url                   = $this->instanceUrl() . '/approve';
		list($response, $opts) = $this->_request( 'post', $url, $params, $opts );
		$this->refreshFrom( $response, $opts );
		return $this;
	}

	/**
	 * @param array|null        $params
	 * @param array|string|null $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return Authorization The declined authorization.
	 */
	public function decline( $params = null, $opts = null ) {
		$url                   = $this->instanceUrl() . '/decline';
		list($response, $opts) = $this->_request( 'post', $url, $params, $opts );
		$this->refreshFrom( $response, $opts );
		return $this;
	}
}
